
From: "Randy.Dunlap" <rddunlap@osdl.org>

Put function prototypes for memset() and memcpy() ahead of where
there are used, to kill sparse warnings:

arch/x86_64/boot/compressed/../../../../lib/inflate.c:317:3: warning: undefined identifier 'memset'
arch/x86_64/boot/compressed/../../../../lib/inflate.c:601:11: warning: undefined identifier 'memcpy'
arch/x86_64/boot/compressed/misc.c:151:2: warning: undefined identifier 'memcpy'
arch/x86_64/boot/compressed/../../../../lib/inflate.c:317:3: warning: call with no type!
arch/x86_64/boot/compressed/../../../../lib/inflate.c:601:17: warning: call with no type!
arch/x86_64/boot/compressed/misc.c:151:9: warning: call with no type!

Signed-off-by: Randy Dunlap <rddunlap@osdl.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/x86_64/boot/compressed/misc.c |    3 +++
 1 files changed, 3 insertions(+)

diff -puN arch/x86_64/boot/compressed/misc.c~x86-64-add-memcpy-memset-prototypes arch/x86_64/boot/compressed/misc.c
--- 25/arch/x86_64/boot/compressed/misc.c~x86-64-add-memcpy-memset-prototypes	2005-03-16 21:43:13.000000000 -0800
+++ 25-akpm/arch/x86_64/boot/compressed/misc.c	2005-03-16 21:43:13.000000000 -0800
@@ -93,6 +93,9 @@ static unsigned long output_ptr = 0;
 static void *malloc(int size);
 static void free(void *where);
  
+void* memset(void* s, int c, unsigned n);
+void* memcpy(void* dest, const void* src, unsigned n);
+
 static void putstr(const char *);
   
 extern int end;
_
